package
  Neo4j::Bolt::CResultStream;
use v5.12;
use warnings;

BEGIN {
  our $VERSION = "0.5002";
  require XSLoader;
  XSLoader::load();
}
1;
